from pkg_resources import get_distribution, DistributionNotFound
import os

# https://stackoverflow.com/questions/17583443/what-is-the-correct-way-to-share-package-version-with-setup-py-and-the-package
try:
    _dist = get_distribution("vitality")
    _dist_loc = os.path.normcase(_dist.location)
    _here = os.path.normcase(__file__)
    if not _here.startswith(os.path.join(_dist_loc, "vitality")):
        # This version is not installed, but another version is.
        raise DistributionNotFound
except DistributionNotFound:
    __version__ = "locally installed"
else:
    __version__ = _dist.version


class Error(Exception):
    pass





from types import SimpleNamespace

from . import Error

DEFAULTS = SimpleNamespace(
    background_color="black",
    title_font_size=120,
    width=1920,
    height=1080,
    font="sans-serif"
)

def presentation_data(config):
    """Converts YML presentation representation into instructions object."""
    data = {
        "title": config.get("title"),
        "defaults": {
            "font": config.get("defaults", {}).get("font", DEFAULTS.font)
        },
        "fonts": config.get("fonts", []),
        "size": {
            "width": config.get("size", {}).get("width", DEFAULTS.width),
            "height": config.get("size", {}).get("height", DEFAULTS.height)
        },
        "slides": []
    }
    for slide in config.get("slides", []):

        # title slide
        if isinstance(slide, str):
            slide = title_slide(slide, data)
            data["slides"].append(slide)
    return data


def title_slide(slide, data):
    return {
        "layout": "title",
        "content": slide,
        "font": data["defaults"]["font"],
        "size": DEFAULTS.title_font_size
    }



import sys
import traceback

import argparse
import jinja2
import termcolor
import yaml

from . import __version__, Error
from .presentation import presentation_data

env = jinja2.Environment(
    loader=jinja2.PackageLoader("vitality", "templates")
)


def main():

    # Parse arguments
    parser = argparse.ArgumentParser(description="Generate presentation slides.")
    parser.add_argument("config", type=str, help="slide configuration file")
    parser.add_argument("-o", "--output", type=str, required=True, help="output file")
    parser.add_argument("-r", "--remote-d3", action="store_true", default=False, help="load d3.js remotely")
    parser.add_argument("-v", "--verbose", action="store_true", help="verbose mode")
    parser.add_argument("-V", "--version", action="version", version=f"%(prog)s {__version__}")
    args = parser.parse_args()

    if args.verbose:
        excepthook.verbose = True
    sys.excepthook = excepthook

    # Read slide configuration file
    try:
        with open(args.config) as f:
            config = yaml.load(f.read())
    except FileNotFoundError:
        raise Error("Configuration file does not exist.")

    # Generate instructions object
    data = presentation_data(config)

    # Render template and generate presentation
    template = env.get_template("presentation.html")
    presentation = template.render(
        data=data,
        remote_d3=args.remote_d3,
        version=__version__
    )
    with open(args.output, "w") as f:
        f.write(presentation)
    termcolor.cprint(f"Presentation generated at {args.output}", color="green")


def excepthook(type, value, tb):
    if excepthook.verbose:
        traceback.print_exception(type, value, tb)
    elif issubclass(type, Error):
        termcolor.cprint(value, color="red")
    else:
        termcolor.cprint("vitality encountered an error. Re-run with --verbose for details.", color="red")
excepthook.verbose = False


if __name__ == "__main__":
    main()



from setuptools import setup, find_packages

setup(
    author="Brian Yu",
    author_email="brian@brianyu.me",
    description="Easily configurable presentation software.",
    entry_points={
        "console_scripts": ["vitality=vitality.__main__:main"]
    },
    install_requires=[
        "argparse>=1.4", "jinja2>=2.10", "pyyaml>=3.13", "termcolor>=1.1"
    ],
    name="vitality",
    packages=["vitality"],
    url="https://github.com/brianyu28/vitality",
    version="0.1.0"
)

